.. _shortest_paths:

Shortest Paths
==============

.. toctree::
   :maxdepth: 2

.. automodule:: networkx.algorithms.shortest_paths.generic
.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/

   shortest_path
   shortest_path_length
   average_shortest_path_length



Advanced Interface
------------------

.. automodule:: networkx.algorithms.shortest_paths.unweighted
.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/

   single_source_shortest_path
   single_source_shortest_path_length
   all_pairs_shortest_path
   all_pairs_shortest_path_length
   predecessor
   floyd_warshall


.. automodule:: networkx.algorithms.shortest_paths.weighted
.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/

   dijkstra_path
   dijkstra_path_length
   single_source_dijkstra_path
   single_source_dijkstra_path_length
   all_pairs_dijkstra_path
   all_pairs_dijkstra_path_length
   single_source_dijkstra
   bidirectional_dijkstra
   bidirectional_shortest_path
   dijkstra_predecessor_and_distance



A* Algorithm
------------

.. automodule:: networkx.algorithms.shortest_paths.astar
.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/

   astar_path
   astar_path_length   

